@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Transport;
 use vars '$VERSION';
-$VERSION = '2.07';
+$VERSION = '2.08';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
 
@@ -80,7 +80,7 @@ sub compileClient(@)
             else { $trace->{error} = "call failed with code $code" }
         }
         elsif($xmlin) { $answer = $xmlin }
-        else { $trace->{error} = 'no xml as answer' }
+        else { $trace->{error} ||= 'no xml as answer' }
 
         my $end = $trace->{transport_end} = time;
 
